import jinja2

env = jinja2.Environment(
    loader=jinja2.PackageLoader("snek5000", "resources"),
    #  loader=jinja2.PackageLoader("snek5000_canonical", "templates"),
    undefined=jinja2.StrictUndefined,
)

box = env.get_template("box.j2")
size = env.get_template("SIZE.j2")
makefile_usr = env.get_template("makefile_usr.inc.j2")



""":orphan:

Deprecated sub-package

"""
import warnings

warnings.warn(
    (
        "Package snek5000.assets will be removed on a later release. "
        "Use snek5000.resources instead."
    ),
    DeprecationWarning,
)



from snek5000_tgv.templates import box, makefile_usr, size

from snek5000 import mpi
from snek5000.output.base import Output as OutputBase


class OutputTGV(OutputBase):
    @property
    def makefile_usr_sources(self):
        """
        Sources for inclusion to makefile_usr.inc
        Dict[directory]  -> list of source files
        """
        return {}

    def post_init(self):
        super().post_init()

        # Write additional source files to compile the simulation
        if mpi.rank == 0 and self._has_to_save and self.sim.params.NEW_DIR_RESULTS:
            self.write_box(box)
            self.write_size(size)
            self.write_makefile_usr(makefile_usr)


Output = OutputTGV
